import { BasicColumn } from '/@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { useUserStore } from '/@/store/modules/user';
import { useMessage } from '/@/hooks/web/useMessage';
import { FormSchema } from '/@/components/Table';
import { useI18n } from '/@/hooks/web/useI18n';
import { setBasStatus } from '/@/api/tigerapi/wms/inspection';
import { formatToDateTime } from '/@/utils/dateUtil';
const { t: bt } = useI18n();
export const columns: BasicColumn[] = [
  {
    title: bt('单据代码'),
    dataIndex: 'BILLCODE',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: '是否烘烤',
    dataIndex: 'NEED_BAKE',
    width: 120,
    customRender: ({ record }) => {
      if (!Reflect.has(record, 'pendingStatus1')) {
        record.pendingStatus1 = false;
      }
      // const id='d70918d6fe474b96b6dabba5c8679c30';
      // const roles = useUserStore().getUserInfo.roles
      // const is_active=roles.some(item=>item.MENU_CODE===id)
      return h(Switch, {
        checked: record.NEED_BAKE === 'Y',
        checkedChildren: '是',
        unCheckedChildren: '否',
        
        //disabled:!is_active,
        loading: record.pendingStatus1,
        onChange(checked: boolean) {
          const oldStatus = record.NEED_BAKE;
          record.pendingStatus1 = true;
          const newStatus = checked ? 'Y' : 'N';
          console.log(10, newStatus);
          const { createMessage } = useMessage();
          record.NEED_BAKE = newStatus;
          record.HANDLED_DATE=formatToDateTime(new Date());
          setBasStatus(record)
            .then(() => {
              createMessage.success(`是否烘烤已成功修改`);
            })
            .catch(() => {
              createMessage.error('修改失败');
              record.NEED_BAKE = oldStatus;
            })
            .finally(() => {
              record.pendingStatus1 = false;
            });
        },
      });
    },
  },
  {
    title: bt('接收数量'),
    dataIndex: 'RECEIVEQTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('复核数量'),
    dataIndex: 'REVIEWQTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('抽样数量'),
    dataIndex: 'SAMPLEQTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('通过数量'),
    dataIndex: 'SAMPLEPASSQTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('抽样完成数量'),
    dataIndex: 'SAMPLENGQTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('开始数量'),
    dataIndex: 'BEGINQTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('结束数量'),
    dataIndex: 'ENDQTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('重大缺陷'),
    dataIndex: 'FATALQTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('严重缺陷数量'),
    dataIndex: 'SERIOUSQTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('一般缺陷数量'),
    dataIndex: 'COMMONLYQTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('轻微缺陷数量'),
    dataIndex: 'SLIGHTQTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('检验数量'),
    dataIndex: 'QCQTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('拒绝数量'),
    dataIndex: 'REJECTQTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('入库数量'),
    dataIndex: 'INSTOCKQTY',
    resizable: true,
    sorter: true,
    width: 180,
  },

];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'BILLCODE',
    label: bt('单据代码'),
    colProps: { span: 8 },
    component: 'Input',
  }
];

export const formSchema: FormSchema[] = [
  {
    field: 'BILLCODE',
    label: '单据代码',
    required: true,
    component: 'Input',
  },
  {
    field: 'REVIEWQTY',
    label: '复核数量',
    required: true,
    component: 'Input',
  },
  {
    field: 'SAMPLEQTY',
    label: '抽样数量',
    required: true,
    component: 'Input',
  },
  {
    field: 'SAMPLEPASSQTY',
    label: '通过数量',
    required: true,
    component: 'Input',
  },
  {
    field: 'SAMPLENGQTY',
    label: '抽样完成数量',
    required: true,
    component: 'Input',
  },
  {
    field: 'BEGINQTY',
    label: '开始数量',
    required: true,
    component: 'Input',
  },
  {
    field: 'ENDQTY',
    label: '结束数量',
    required: true,
    component: 'Input',
  },
  {
    field: 'FATALQTY',
    label: '重大缺陷',
    component: 'Input',
    required: true,
  },
  {
    field: 'SERIOUSQTY',
    label: '严重缺陷数量',
    component: 'Input',
    required: true,
  },
  {
    field: 'COMMONLYQTY',
    label: '一般缺陷数量',
    component: 'Input',
    required: true,
  },
  {
    field: 'SLIGHTQTY',
    label: '轻微缺陷数量',
    component: 'Input',
    required: true,
  },
  {
    field: 'QCQTY',
    label: '检验数量',
    component: 'Input',
    show: true,
  },
  {
    field: 'RECEIVEQTY',
    label: '接收数量',
    component: 'Input',
    show: true,
  },
  {
    field: 'REJECTQTY',
    label: '拒绝数量',
    component: 'Input',
    show: true,
  },
  {
    field: 'INSTOCKQTY',
    label: '入库数量',
    component: 'Input',
    show: true,
  },
];
